@@ -2,6 +2,8 @@ package ## Hide from PAUSE
  MooseX::Meta::TypeConstraint::Structured;
 # ABSTRACT: Structured type constraints
 
+our $VERSION = '0.36';
+
 use Moose;
 use Devel::PartialDump;
 use MooseX::Meta::TypeCoercion::Structured;
@@ -113,12 +115,9 @@ sub generate_constraint_for {
     return $self->constraint_generator->($self, $type_constraints);
 }
 
-#pod =begin :prelude
-#pod
+#pod =for :prelude
 #pod =for stopwords parameterize
 #pod
-#pod =end :prelude
-#pod
 #pod =method parameterize (@type_constraints)
 #pod
 #pod Given a ref of type constraints, create a structured type.
@@ -370,7 +369,7 @@ MooseX::Meta::TypeConstraint::Structured - Structured type constraints
 
 =head1 VERSION
 
-version 0.34
+version 0.36
 
 =for stopwords parameterize
 
@@ -454,6 +453,17 @@ The following modules or resources may be of interest.
 
 L<Moose>, L<Moose::Meta::TypeConstraint>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-Structured>
+(or L<bug-MooseX-Types-Structured@rt.cpan.org|mailto:bug-MooseX-Types-Structured@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHORS
 
 =over 4
